#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 css-text
version:              0.1.3.0
visibility:           public
id:                   css-text-0.1.3.0-894LoX01qWeCaArYaaalsu
key:                  css-text-0.1.3.0-894LoX01qWeCaArYaaalsu
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/yesodweb/css-text.git#readme
synopsis:             CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>

category:             Web, Yesod
abi:                  e01eceb81ff67def20225cafeb9cf699
exposed:              True
exposed-modules:      Text.CSS.Parse Text.CSS.Render
hidden-modules:       Paths_css_text
import-dirs:          /usr/lib/ghc-8.10.5/site-local/css-text-0.1.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/css-text-0.1.3.0
hs-libraries:         HScss-text-0.1.3.0-894LoX01qWeCaArYaaalsu
depends:
    attoparsec-0.14.1-IwUGXYiDhQIB5nUHrI5Wg8 base-4.14.2.0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html:         /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

